Index: branches/5.1.x/install.php
===================================================================
--- branches/5.1.x/install.php	(revision 13116)
+++ branches/5.1.x/install.php	(revision 13117)
@@ -1,53 +1,53 @@
 <?php
 /**
 * @version	$Id$
 * @package	In-Bulletin
 * @copyright	Copyright (C) 1997 - 2009 Intechnic. All rights reserved.
 * @license      GNU/GPL
 * In-Portal is Open Source software.
 * This means that this software may have been modified pursuant
 * the GNU General Public License, and as distributed it includes
 * or is derivative of works licensed under the GNU General Public License
 * or other free or open source software licenses.
 * See http://www.in-portal.org/license for copyright notices and details.
 */
-	$module_folder = 'in-bulletin';
+	$module_folder = 'modules/in-bulletin';
 
 	if (!defined('IS_INSTALL')) {
 		// separate module install
 		define('IS_INSTALL', 1);
 		define('ADMIN', 1);
 		define('REL_PATH', $module_folder);
-		define('FULL_PATH', realpath(dirname(__FILE__) . '/..') );
+		define('FULL_PATH', realpath(dirname(__FILE__) . '/../..') );
 
 		include_once(FULL_PATH . '/core/kernel/startup.php');
 		require_once FULL_PATH . '/core/install/install_toolkit.php';
 
 		$toolkit = new kInstallToolkit();
 	}
 	else {
 		// install, using installation wizard
 		$toolkit =& $this->toolkit;
 		/* @var $toolkit kInstallToolkit */
 	}
 
 	$application =& kApplication::Instance();
 	$application->Init();
 
 	if ($application->RecallVar('user_id') != -1) {
 		die('restricted access!');
 	}
 
 	$category =& $toolkit->createModuleCategory('Forums', 'Discussion Forums', '#in-bulletin/section_design#', 'in-bulletin/img/menu_topics.gif');
 
 	$toolkit->RunSQL('/' . $module_folder . '/install/install_schema.sql');
 	$toolkit->RunSQL('/' . $module_folder . '/install/install_data.sql', '{TopicCatId}', $category->GetID());
 	$toolkit->ImportLanguage('/' . $module_folder . '/install/english');
 
-	$toolkit->SetModuleRootCategory($module_folder, $category->GetID());
+	$toolkit->SetModuleRootCategory(basename($module_folder), $category->GetID());
 
 //	$toolkit->linkCustomFields($module_folder, 'bb', 3); // to create Custom Fields for Topics
 	$toolkit->linkCustomFields('KERNEL', 'c', 1); // to create ItemTemplate custom field
 	$toolkit->setModuleItemTemplate($category, 'bb', '#in-bulletin/item_design#');
 
-	$toolkit->finalizeModuleInstall($module_folder, true);
\ No newline at end of file
+	$toolkit->finalizeModuleInstall(basename($module_folder), true);
\ No newline at end of file
@@ -1,53 +1,53 @@
 
-//	$toolkit->linkCustomFields($module_folder, 'bb', 3); // to create Custom Fields for Topics
+//	$toolkit->linkCustomFields(basename($module_folder), 'bb', 3); // to create Custom Fields for Topics
 	$toolkit->linkCustomFields('KERNEL', 'c', 1); // to create ItemTemplate custom field
 	$toolkit->setModuleItemTemplate($category, 'bb', '#in-bulletin/item_design#');